@@ -23,7 +23,7 @@
 #include "mtcompare_sumaclust.h"
 #include "sumaclust.h"
 
-#define VERSION "1.0.10"
+#define VERSION "1.0.20"
 
 
 /* ----------------------------------------------- */
@@ -73,9 +73,10 @@ static void PrintHelp()
         PP      " -f       : Output in FASTA format is deactivated.\n");
         PP      "\n");
         PP      "------------------------------------------------------------\n");
-        PP      " Argument : the nucleotide dataset to cluster\n");
+        PP      " Argument : the nucleotide dataset to cluster (or nothing   \n");
+        PP      "            if the standard input should be used).          \n");
         PP      "------------------------------------------------------------\n");
-        PP		" http://metabarcoding.org/sumatra\n");
+        PP		" http://metabarcoding.org/sumaclust\n");
         PP      "------------------------------------------------------------\n\n");
 }
 
@@ -794,7 +795,6 @@ int main(int argc, char** argv)
 	BOOL			reverse		     = FALSE;
 	BOOL			onlyATGC	     = TRUE;
 	int             reference        = ALILEN;
-	int             ndb              = 0;
 	int				nproc            = 1;
 	BOOL			printBIOM        = FALSE;
 	BOOL			printOTUtable    = FALSE;
@@ -941,10 +941,6 @@ int main(int argc, char** argv)
 		}
 	}
 
-	ndb = argc - optind;
-	if (ndb != 1)
-        errflag++;
-
 	if (errflag)
 		ExitUsage(errflag);
 
@@ -965,6 +961,7 @@ int main(int argc, char** argv)
 
 	fprintf(stderr,"Reading dataset...");
 	db = seq_readAllSeq2(argv[optind], TRUE, onlyATGC);
+
 	fprintf(stderr,"\n%d sequences\n",db.count);
 
 	if (db.count == 0)
